@@ -3,6 +3,16 @@ import os
 import csv
 import datetime
 from importlib import import_module
+from io import BytesIO
+from dativa.tools.aws import S3Location
+
+try:
+    import boto3
+
+    from botocore.exceptions import ClientError
+except ImportError:
+    boto3 = None
+    ClientError = None
 
 try:
     import sqlparse
@@ -109,6 +119,7 @@ class SqlClient:
             self._logger.warning('humourous mode engaged, use at own risk')
         self._counter = 0
         self._log_query_text = log_query_text
+        self._archive = dict()  # initialise a dict for path: contents for archiving
 
     @staticmethod
     def _clean_dict(d):
@@ -134,8 +145,10 @@ class SqlClient:
                 pass  # probably shouldn't have been doing it anyway.
 
         if self._log_query_text:
+            # we neither test nor run this code ever
             for line in query.split("\n"):
-                self._logger.log(self.logging_level, "{0:03} {1}".format(i, line))
+                self._logger.log(self.logging_level, "{0:03} {1}".format(self._counter, line))
+                self._increment_counter()
 
     def _clear_archive(self, file):
         if file:
@@ -144,12 +157,51 @@ class SqlClient:
             # clear the file
             open(file, 'w').close()
             self._logger.log(self.logging_level, 'logging query to file: {}'.format(file))
+            self._archive[file] = BytesIO()
 
     def _archive_query(self, logged_query, parameters, file):
-        with open(file, 'a+') as f:
-            f.write('-- Ran query on: {:%Y-%m-%d %H:%M:%S}\n'.format(datetime.datetime.now()))
-            f.write('-- Parameters: {0}\n'.format(self._clean_dict(parameters)))
-            f.write(logged_query + ';\n')
+
+        f = self._archive[file]
+
+        f.write('-- Ran query on: {:%Y-%m-%d %H:%M:%S}\n'.format(datetime.datetime.now()).encode('utf-8'))
+        f.write('-- Parameters: {0}\n'.format(self._clean_dict(parameters)).encode('utf-8'))
+        f.write(logged_query.encode('utf-8') + b';\n')
+
+    def _save_archive(self, file):
+
+        try:
+            if file:
+
+                contents = self._archive[file]
+                contents.seek(0)
+                if file.startswith('s3://'):
+                    s3_path = S3Location(file)
+                    if not boto3:
+                        raise ImportError('boto3 must be installed to archive queries to s3')
+                    s3 = boto3.client('s3')
+                    archive_text = contents.read()  # boto closes this, but i want to keep it just in case
+                    contents.seek(0)
+                    s3.upload_fileobj(contents, s3_path.bucket, s3_path.key)
+                else:
+                    with open(file, 'wb') as f:
+                        f.write(contents.read())
+        except (ImportError,) as e:
+            self._logger.error('could not archive query due to {0}: {1}\n'
+                               'BytesIO archive can be accessed from Sql_Client._archive["{2}"]'.format(
+                type(e),
+                str(e),
+                file
+            ))
+            contents.seek(0)
+        except ClientError as e:  # only resolved if not import error, so no issues
+            self._logger.error('could not archive query due to {0}: {1}\n'
+                               'BytesIO archive can be accessed from Sql_Client._archive["{2}"]'.format(
+                type(e),
+                str(e),
+                file
+            ))
+            # restore the archive
+            self._archive[file] = BytesIO(archive_text)
 
     def _report_rowcount(self, execution_time):
         if self.cursor.rowcount >= 0:
@@ -177,15 +229,13 @@ class SqlClient:
 
         # split into multiple commands....
         if ';' in text:
-            if not sqlparse:
-                # split into multiple commands....
-                for command in text.split(";"):
-                    if command.strip() != "":
-                        yield command.strip()
-            else:
-                for command in sqlparse.split(text):
-                    if command.strip() != "":
-                        yield command.strip()
+            # use sql parse if installed, otherwise split on every ;
+            generator = sqlparse.split(text) if sqlparse else text.split(";")
+
+            # split into multiple commands....
+            for command in generator:
+                if command.strip() not in ["", "';'"]:
+                    yield command.strip()
         else:
             yield text.strip()
 
@@ -249,6 +299,7 @@ class SqlClient:
             self._increment_counter()
 
         self.connection.commit()
+        self._save_archive(archive_query)
 
     def execute_query_to_df(self, query, parameters=None, replace=None, first_to_run=1, dry_run=False,
                             archive_query=False):
@@ -290,6 +341,7 @@ class SqlClient:
                                    archive_query=archive_query)
 
         self.connection.commit()
+        self._save_archive(archive_query)
 
         if not dry_run and len(df) == 0:
             self._logger.info("No results returned")
@@ -350,3 +402,5 @@ class SqlClient:
 
                 for row in self.cursor:
                     writer.writerow(row)
+
+        self._save_archive(archive_query)
