@@ -8,10 +8,9 @@ from io import StringIO, BytesIO
 from csv import Sniffer, Error
 from dativa.tools.aws import S3Location, S3ClientError
 from functools import wraps
-from os import path
+import os
 import gzip
 import zipfile
-import s3fs
 import warnings
 
 try:
@@ -34,6 +33,11 @@ try:
 except ImportError:
     pd = None
 
+try:
+    import s3fs
+except ImportError:
+    s3fs = None
+
 try:
     from chardet.universaldetector import UniversalDetector
 except ImportError:
@@ -96,7 +100,6 @@ class CSVHandler:
     allowed_write_compressions = {'gzip', 'infer', 'zip'}
 
     detect_parameters = False
-    base_path = ""
     include_index = False
     compression = 'infer'
     nan_values = None
@@ -125,11 +128,14 @@ class CSVHandler:
         if not pd:
             raise ImportError("pandas must be installed to run CSVHandler")
 
-        self.s3fs_version_number = int(s3fs.__version__.split('.')[1]) if int(
-            s3fs.__version__.split('.')[0]) == 0 else 3
-        if self.s3fs_version_number >= 3:
-            warnings.warn('You are using version {} of s3fs it is recommended to use 0.1.5 =< s3fs <0.3.0.'.format(
-                s3fs.__version__))
+        if s3fs is None:
+            self.s3fs_version_number = 0
+        else:
+            self.s3fs_version_number = int(s3fs.__version__.split('.')[1]) if int(
+                s3fs.__version__.split('.')[0]) == 0 else 3
+            if self.s3fs_version_number >= 3:
+                warnings.warn('You are using version {} of s3fs it is recommended to use 0.1.5 =< s3fs <0.3.0.'.format(
+                    s3fs.__version__))
 
         self._process_kwargs(**kwargs)
 
@@ -196,6 +202,9 @@ class CSVHandler:
             if not UniversalDetector:
                 raise ImportError("chardet must be installed to use detect_parameters in dativa.tools CSVHandler")
 
+        if self.line_terminator is None:
+            self.line_terminator = os.linesep
+
     @property
     def s3_client(self):
         if not self.s3c:
@@ -237,7 +246,7 @@ class CSVHandler:
         return False
 
     def _get_file(self, file):
-        return path.join(self.base_path, file)
+        return os.path.join(self.base_path, file)
 
     def _get_df_from_raw(self, file):
         """
@@ -290,7 +299,8 @@ class CSVHandler:
         except EOFError as e:
             if self.s3fs_version_number >= 3:
                 raise type(e)(
-                    e.message + 'This error can be caused by a bug in s3fs version 3 and above if compression is specified')
+                    e.message +
+                    'This error can be caused by a bug in s3fs version 3 and above if compression is specified')
             else:
                 raise e
 
